* This do file will replicate the analysis presented in Katja Kleinberg and Benjamin Fordham,
* "Don't Know Much about Foreign Policy: Assessing the Impact of "Don't Know" and "No Opinion" 
* Responses on Inferences aboutForeign Policy Attitudes," to be published in Foreign Policy Analysis.

* There are two data files, one from a survey the authors conducted through the Time-Sharing Experiments
* in the Social Sciences (TESS) project. The other is a replication file from Jens Hainmueller and Michael Hiscox.
* The replication begins using the first of these files.

* Before running this file, place the contents of the replication data file into a common directory,
* then change to that directory in Stata

use "KF_FPA_replication.dta", clear
svyset weight

* These commands transform the questions we analyze from 5 categories to 3
gen tradeq2=tradeq
recode tradeq2 (-1=.) (1=2) (2=2) (3=1) (4=1) (5=0)

gen forceq2=forceq
recode forceq2 (-1=.) (1=2) (2=2) (3=1) (4=1) (5=0)

gen isolatq2=isolatq
recode isolatq2 (-1=.) (1=2) (2=2) (3=1) (4=1) (5=0)

* These commands set up the 2 category dependent variables for logit models
gen tradeql=tradeq
recode tradeql (-1=.) (1=1) (2=1) (3=0) (4=0) (5=.)

gen forceql=forceq
recode forceql (-1=.) (1=1) (2=1) (3=0) (4=0) (5=.)

gen isolatql=isolatq
recode isolatql (-1=.) (1=1) (2=1) (3=0) (4=0) (5=.)


* These commands set up the independent variables for our analysis
gen incquint=ppincimp
recode incquint (1=1) (2=1) (3=1) (4=1) (5=1) (6=1) (7=2) (8=2) (9=2) (10=2) (11=3) (12=3) (13=4) (14=4) (15=4) (16=5) (17=5) (18=5) (19=5) 

gen male=ppgender
recode male (1=1) (2=0)

gen strongdem=party7
recode strongdem (1=0) (2=0) (3=0) (4=0) (5=0) (6=0) (7=1)

gen strongrep=party7
recode strongrep (1=1) (2=0) (3=0) (4=0) (5=0) (6=0) (7=0)


* Table 2
svy: tab tradeq2 if xcondition==1
svy: tab tradeq2 if xcondition==2
svy: tab forceq2 if xcondition==1
svy: tab forceq2 if xcondition==2
svy: tab isolatq2 if xcondition==1
svy: tab isolatq2 if xcondition==2


* Table 3
* Trade question 
svy: mlogit tradeq2 i.ppeducat i.male ppage i.strongdem i.strongrep if xcondition==1, baseoutcome(1)
testparm i.ppeducat, equation(0)
testparm i.ppeducat, equation(2)
svy: logit tradeql i.ppeducat i.male ppage i.strongdem i.strongrep if xcondition==2
testparm i.ppeducat
* Use of force question
svy: mlogit forceq2 i.ppeducat i.male ppage i.strongdem i.strongrep if xcondition==1, baseoutcome(1)
testparm i.ppeducat, equation(0)
testparm i.ppeducat, equation(2)
svy: logit forceql i.ppeducat i.male ppage i.strongdem i.strongrep if xcondition==2
testparm i.ppeducat
* Internationalism-isolationism question
svy: mlogit isolatq2 i.ppeducat i.male ppage i.strongdem i.strongrep if xcondition==1, baseoutcome(1)
testparm i.ppeducat, equation(0)
testparm i.ppeducat, equation(2)
svy: logit isolatql i.ppeducat i.male ppage i.strongdem i.strongrep if xcondition==2
testparm i.ppeducat


* Table 4
svy: logit tradeql i.ppeducat i.male ppage i.strongdem i.strongrep if xcondition==1
testparm i.ppeducat
svy: logit forceql i.ppeducat i.male ppage i.strongdem i.strongrep if xcondition==1
testparm i.ppeducat
svy: logit isolatql i.ppeducat i.male ppage i.strongdem i.strongrep if xcondition==1
testparm i.ppeducat


* The following will replicate our re-analysis of the data from Hainmueller and Hiscox's IO article
* We begin by setting up their data as they did, using their replication code
* Our results are reported in Figure 3

use nes1992.dta, clear
* Start HH2006 replication code

/* *************************************************************************************************************************** */
/* Recodings from raw dataset NES 1992 */

/* DV */
gen     trade_opinion=. 
replace trade_opinion=1 if v923802==1
replace trade_opinion=0 if v923802==5

/* Treatment Vars: Skill Proxies */
/* Schooling */
gen     schooling=v923905
replace schooling=. if v923905==96
replace schooling=. if v923905==99
replace schooling=. if v923905==.
/* Note cap at 17 years of schooling */

/* Attainment Dummies */
gen     college=. 
replace college=1 if v923908==6 
replace college=0 if v923908~=6
replace college=. if v923908==0 | v923908==98 | v923908==99 | v923908==.

gen     graduate=1 if v923908==7 
replace graduate=0 if v923908~=7 
replace graduate=. if v923908==0 | v923908==98 | v923908==99 | v923908==.

gen     communitycol=1 if v923908==5 | v923908==4 /* some years of post high school education (including junior or community college) */
replace communitycol=0 if v923908~=5 & v923908~=4
replace communitycol=. if v923908==0 | v923908==98 | v923908==99 | v923908==.

gen     highschool=.
replace highschool=1 if v923908==3
replace highschool=0 if v923908~=3 
replace highschool=. if v923908==0 | v923908==98 | v923908==99 | v923908==.

gen     juniorhigh=. 
replace juniorhigh=1 if v923905==8  /* 8 years of schooling completed */
replace juniorhigh=0 if v923905~=8 
replace juniorhigh=. if v923905==96 | v923905==99 | v923905==. 

/* Covariates */
/* Limited Set */
gen     age=v923903
replace age=. if v923903==.

/* age dummies used for robustness only */
gen      agedu18_29=.
replace  agedu18_29=0 if age~=.
replace  agedu18_29=1 if age>=18 & age<=29
gen      agedu30_44=.
replace  agedu30_44=0 if age~=.
replace  agedu30_44=1 if age>=30 & age<=44
gen      agedu45_59=.
replace  agedu45_59=0 if age~=.
replace  agedu45_59=1 if age>=45 & age<=59

gen     male=v924201
replace male=0 if v924201==2
replace male=. if v924201==.
gen     race=v924202
replace race=. if v924202==. | v924202==0 | v924202==9
label   define race 1 White 2 Black 3 Indian 4 Asian
label   values race race
tab     race, gen(RACE)
rename  RACE1 White
rename  RACE2 Black
rename  RACE3 Indian
rename  RACE4 Asian
drop    race

/* Extensive Covariate set */
gen     TUrecoding=1 if v924102==11 | v924102==20 | v924102==21 | v924102==32
replace TUrecoding=0 if v924102==13 | v924102==14 | v924102==15 | v924102==26
gen     TUmember=1 if v924101==1 & TUrecoding==1
replace TUmember=0 if v924101==5 | TUrecoding==0
drop    TUrecoding
gen     partyid=v923634
replace partyid=. if v923634==. | v923634==7 | v923634==8 | v923634==9
label   values partyid v923634
gen     ideology=2 if v923513==1
replace ideology=1 if v923513==3 
replace ideology=0 if v923513==5
label   define ideology 2 Liberal 1 Moderate 0 Conservative
label   values ideology ideology 

/* Married or currently living with partner */
/* Sample delimiter used for table 3        */
gen     partner=1 if v923909==1
replace partner=0 if v923909==2

/* Tolerance proxies (these are just used for the additional tests in the web appendix) */

gen      trueamerican=v923523 
replace  trueamerican=. if v923523==. | v923523==0 | v923523==8 | v923523==9
gen      ETHNO_DISTINCT=1 if v923524==1 
replace  ETHNO_DISTINCT=0  if v923524==3 | v923524==5
gen      ETHNO_BLEND=1 if v923524==5 
replace  ETHNO_BLEND=0  if v923524==3    | v923524==1
gen      treatequal=v923522
replace  treatequal=. if v923522==. | v923522==0 | v923522==8 | v923522==9
gen      adjust=v926115    
replace  adjust=.  if v926115==. | v926115==0 | v926115==8 | v926115==9

/* Sample weight */
gen weight=v923008  
/* *************************************************************************************************************************** */
* End HH2006 replication code

* We created an additional trade variable with DKNOs included rather than treated
* as missing data
* Note that for trade_opinion, 1=favor new limits, 0=oppose new limits, 2=DKNO
gen     trade_opinion2=. 
replace trade_opinion2=1 if v923802==1
replace trade_opinion2=0 if v923802==5
replace trade_opinion2=2 if v923802==0
replace trade_opinion2=2 if v923802==8

svyset weight
svy: probit trade_opinion i.juniorhigh i.highschool i.communitycol i.college i.graduate White Black Indian age male
margins, dydx(juniorhigh) at(highschool=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0)
margins, dydx(highschool) at(juniorhigh=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0)
margins, dydx(communitycol) at(juniorhigh=0 highschool=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0)
margins, dydx(college) at(juniorhigh=0 highschool=0 communitycol=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0)
margins, dydx(graduate) at(juniorhigh=0 highschool=0 communitycol=0 college=0 White=1 Black=0 Indian=0 age=46 male=0)

svy: mlogit trade_opinion2 i.juniorhigh i.highschool i.communitycol i.college i.graduate White Black Indian age male
margins, dydx(juniorhigh) at(highschool=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(2))
margins, dydx(highschool) at(juniorhigh=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(2))
margins, dydx(communitycol) at(juniorhigh=0 highschool=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(2))
margins, dydx(college) at(juniorhigh=0 highschool=0 communitycol=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(2))
margins, dydx(graduate) at(juniorhigh=0 highschool=0 communitycol=0 college=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(2))

margins, dydx(juniorhigh) at(highschool=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(0))
margins, dydx(highschool) at(juniorhigh=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(0))
margins, dydx(communitycol) at(juniorhigh=0 highschool=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(0))
margins, dydx(college) at(juniorhigh=0 highschool=0 communitycol=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(0))
margins, dydx(graduate) at(juniorhigh=0 highschool=0 communitycol=0 college=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(0))

margins, dydx(juniorhigh) at(highschool=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(1))
margins, dydx(highschool) at(juniorhigh=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(1))
margins, dydx(communitycol) at(juniorhigh=0 highschool=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(1))
margins, dydx(college) at(juniorhigh=0 highschool=0 communitycol=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(1))
margins, dydx(graduate) at(juniorhigh=0 highschool=0 communitycol=0 college=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(1))

* We conducted the same exercise for the 1996 ANES; use their replication data and code,
* then adding an additional dependent variable and analysis

* First running their replication code on the 1996 NES data they used
use nes1996.dta, clear

* Start HH2006 replication code
/* *************************************************************************************************************************** */
/* Recodings from raw dataset NES 1996 */

/* DV */
gen     trade_opinion=.
replace trade_opinion=1 if v961327==1
replace trade_opinion=0 if v961327==5

/* Treatment Vars: Skill Proxies */

/* Schooling */
gen     schooling=v960607
replace schooling=. if v960607==99 | v960607==.
/* Note cap at 17 years of schooling */

/* Attainment Dummies */
gen     graduate=1 if  v960610==7
replace graduate=0 if  v960610~=7
replace graduate=. if  v960610==. | v960610==9

gen     college=1 if v960610==6 
replace college=0 if v960610~=6
replace college=. if v960610==. | v960610==9

gen     communitycol=1 if v960610==5 | v960610==4 /* some years of post high school education (including junior or community college) */
replace communitycol=0 if v960610~=5 & v960610~=4
replace communitycol=. if v960610==. | v960610==9

gen     highschool=1 if v960610==3 
replace highschool=0 if v960610~=3
replace highschool=. if v960610==. | v960610==9

gen     juniorhigh=1 if v960607==8 /* 8 years of schooling completed */
replace juniorhigh=0 if v960607~=8 
replace juniorhigh=. if v960607==. | v960607==99 

/* Covariates */
/* Limted  Set */
gen      age=v960605  
replace  age=. if v960605==99 | v960605==.

/* age dummies used for robustness only */
gen      agedu18_29=.
replace  agedu18_29=0 if age~=.
replace  agedu18_29=1 if age>=18 & age<=29
gen      agedu30_44=.
replace  agedu30_44=0 if age~=.
replace  agedu30_44=1 if age>=30 & age<=44
gen      agedu45_59=.
replace  agedu45_59=0 if age~=.
replace  agedu45_59=1 if age>=45 & age<=59

gen     male=v960066
replace male=0 if v960066==2
replace male=. if v960066==.
gen     race=v960067
replace race=. if v960067==. | v960067==9
label   define race 1 White 2 Black 3 Indian 4 Asian
label   values race race
tab     race, gen(RACE)
rename  RACE1 White
rename  RACE2 Black
rename  RACE3 Indian
rename  RACE4 Asian
drop    race

/* Extensive Set */
gen     YUrecoding=1 if v960699==11 | v960699==21 | v960699==22 
replace YUrecoding=0 if v960699==12 | v960699==12 | v960699==23 
gen     TUmember=1 if v960698==1 & YUrecoding==1
replace TUmember=0 if v960698==5 | YUrecoding==0
drop    YUrecoding
gen     partyid=v960420
replace partyid=. if v960420==. | v960420==7 | v960420==8 | v960420==9
label   values partyid v960420
gen     house=1 if v960714==1
replace house=0 if v960714~=1
replace house=. if v960714==. | v960714==9 
gen     ideology=2 if v960368==1
replace ideology=1 if v960368==3 
replace ideology=0 if v960368==5
label   define ideology 2 Liberal 1 Moderate 0 Conservative
label   values ideology ideology 


/* Sample weight */
gen weight=v960003
/* *************************************************************************************************************************** */
* End HH2006 replication code

gen     trade_opinion2=.
replace trade_opinion2=1 if v961327==1
replace trade_opinion2=0 if v961327==5
replace trade_opinion2=2 if v961327==0
replace trade_opinion2=2 if v961327==8

svyset weight
svy: probit trade_opinion i.juniorhigh i.highschool i.communitycol i.college i.graduate White Black Indian age male
margins, dydx(juniorhigh) at(highschool=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0)
margins, dydx(highschool) at(juniorhigh=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0)
margins, dydx(communitycol) at(juniorhigh=0 highschool=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0)
margins, dydx(college) at(juniorhigh=0 highschool=0 communitycol=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0)
margins, dydx(graduate) at(juniorhigh=0 highschool=0 communitycol=0 college=0 White=1 Black=0 Indian=0 age=46 male=0)

svy: mlogit trade_opinion2 i.juniorhigh i.highschool i.communitycol i.college i.graduate White Black Indian age male
margins, dydx(juniorhigh) at(highschool=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(2))
margins, dydx(highschool) at(juniorhigh=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(2))
margins, dydx(communitycol) at(juniorhigh=0 highschool=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(2))
margins, dydx(college) at(juniorhigh=0 highschool=0 communitycol=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(2))
margins, dydx(graduate) at(juniorhigh=0 highschool=0 communitycol=0 college=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(2))

margins, dydx(juniorhigh) at(highschool=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(0))
margins, dydx(highschool) at(juniorhigh=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(0))
margins, dydx(communitycol) at(juniorhigh=0 highschool=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(0))
margins, dydx(college) at(juniorhigh=0 highschool=0 communitycol=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(0))
margins, dydx(graduate) at(juniorhigh=0 highschool=0 communitycol=0 college=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(0))

margins, dydx(juniorhigh) at(highschool=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(1))
margins, dydx(highschool) at(juniorhigh=0 communitycol=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(1))
margins, dydx(communitycol) at(juniorhigh=0 highschool=0 college=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(1))
margins, dydx(college) at(juniorhigh=0 highschool=0 communitycol=0 graduate=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(1))
margins, dydx(graduate) at(juniorhigh=0 highschool=0 communitycol=0 college=0 White=1 Black=0 Indian=0 age=46 male=0) predict(outcome(1))

